@@ -11,10 +11,6 @@
 #ifndef __PREFS_H__
 #define __PREFS_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
 #include <glib.h>
 
 #include <epan/params.h>
@@ -24,6 +20,10 @@ extern "C" {
 
 #include "ws_symbol_export.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #define DEF_WIDTH 750
 #define DEF_HEIGHT 550
 
@@ -34,6 +34,9 @@ extern "C" {
 #define ST_DEF_BURSTLEN 100
 #define ST_MAX_BURSTRES 600000 /* somewhat arbirary limit of 10 minutes */
 #define ST_MAX_BURSTBUCKETS 100 /* somewhat arbirary limit - more buckets degrade performance */
+#define DEF_GUI_DECIMAL_PLACES1 2
+#define DEF_GUI_DECIMAL_PLACES2 4
+#define DEF_GUI_DECIMAL_PLACES3 6
 
 struct epan_uat;
 struct _e_addr_resolve;
@@ -91,7 +94,8 @@ typedef enum {
     layout_pane_content_none,
     layout_pane_content_plist,
     layout_pane_content_pdetails,
-    layout_pane_content_pbytes
+    layout_pane_content_pbytes,
+    layout_pane_content_pdiagram,
 } layout_pane_content_e;
 
 /*
@@ -172,6 +176,8 @@ typedef struct _e_prefs {
   gchar       *gui_start_title;
   version_info_e gui_version_placement;
   guint        gui_max_export_objects;
+  guint        gui_max_tree_items;
+  guint        gui_max_tree_depth;
   layout_type_e gui_layout_type;
   layout_pane_content_e gui_layout_content_1;
   layout_pane_content_e gui_layout_content_2;
@@ -179,7 +185,7 @@ typedef struct _e_prefs {
   gchar       *gui_interfaces_hide_types;
   gboolean     gui_interfaces_show_hidden;
   gboolean     gui_interfaces_remote_display;
-  gint         console_log_level;
+  gboolean     gui_io_graph_automatic_update;
   gchar       *capture_device;
   gchar       *capture_devices_linktypes;
   gchar       *capture_devices_descr;
@@ -212,12 +218,17 @@ typedef struct _e_prefs {
   gboolean     unknown_colorfilters; /* Warn when saving unknown or obsolete color filters. */
   gboolean     gui_qt_packet_list_separator;
   gboolean     gui_qt_packet_header_column_definition;
+  gboolean     gui_qt_packet_list_hover_style; /* Enable/Disable mouse-over colorization */
   gboolean     gui_qt_show_selected_packet;
   gboolean     gui_qt_show_file_load_time;
-  gboolean     gui_packet_editor; /* Enable Packet Editor */
   elide_mode_e gui_packet_list_elide_mode;
   gboolean     gui_packet_list_show_related;
   gboolean     gui_packet_list_show_minimap;
+  gint         gui_decimal_places1; /* Used for type 1 calculations */
+  gint         gui_decimal_places2; /* Used for type 2 calculations */
+  gint         gui_decimal_places3; /* Used for type 3 calculations */
+  gboolean     gui_rtp_player_use_disk1;
+  gboolean     gui_rtp_player_use_disk2;
   gboolean     st_enable_burstinfo;
   gboolean     st_burst_showcount;
   gint         st_burst_resolution;
@@ -301,7 +312,6 @@ WS_DLL_PUBLIC module_t *prefs_register_codec(const char *name, const char *title
  * Register that a protocol has preferences and group it under a single
  * subtree
  */
-#define PREFERENCE_GROUPING
 WS_DLL_PUBLIC module_t *prefs_register_protocol_subtree(const char *subtree, int id,
     void (*apply_cb)(void));
 
@@ -309,7 +319,7 @@ WS_DLL_PUBLIC module_t *prefs_register_protocol_subtree(const char *subtree, int
  * Register that a protocol used to have preferences but no longer does,
  * by creating an "obsolete" module for it.
  */
-module_t *prefs_register_protocol_obsolete(int id);
+WS_DLL_PUBLIC module_t *prefs_register_protocol_obsolete(int id);
 
 /*
  * Callback function for module list scanners.
@@ -514,6 +524,14 @@ void prefs_register_decode_as_preference(module_t *module, const char *name,
 WS_DLL_PUBLIC void prefs_register_obsolete_preference(module_t *module,
     const char *name);
 
+/*
+ * Mark a preference that affects fields change. This works for bool, enum,
+ * int, string (containing filename), range preferences. UAT is not included,
+ * because you can specified UAT_AFFECTS_FIELDS at uat_new().
+ */
+WS_DLL_PUBLIC void prefs_set_preference_effect_fields(module_t *module,
+    const char *name);
+
 
 typedef guint (*pref_cb)(pref_t *pref, gpointer user_data);
 
