@@ -396,7 +396,8 @@ void cf_set_rfcode(capture_file *cf, dfilter_t *rfcode);
 cf_status_t cf_filter_packets(capture_file *cf, gchar *dfilter, gboolean force);
 
 /**
- * At least one "Refence Time" flag has changed, rescan all packets.
+ * Scan through all frame data and recalculate the ref time
+ * without rereading the file.
  *
  * @param cf the capture file
  */
@@ -690,24 +691,24 @@ cf_merge_files_to_tempfile(gpointer pd_window, char **out_filenamep,
 void cf_update_section_comment(capture_file *cf, gchar *comment);
 
 /*
- * Get the comment on a packet (record).
- * If the comment has been edited, it returns the result of the edit,
- * otherwise it returns the comment from the file.
+ * Get the packet block for a packet (record).
+ * If the block has been edited, it returns the result of the edit,
+ * otherwise it returns the block from the file.
  *
  * @param cf the capture file
  * @param fd the frame_data structure for the frame
- * @returns A comment (use g_free to free) or NULL if there is none.
+ * @returns A block (use wtap_block_unref to free) or NULL if there is none.
  */
-char *cf_get_packet_comment(capture_file *cf, const frame_data *fd);
+wtap_block_t cf_get_packet_block(capture_file *cf, const frame_data *fd);
 
 /**
- * Update(replace) the comment on a capture from a frame
+ * Update(replace) the block on a capture from a frame
  *
  * @param cf the capture file
  * @param fd the frame_data structure for the frame
- * @param new_comment the string replacing the old comment
+ * @param new_block the block replacing the old block
  */
-gboolean cf_set_user_packet_comment(capture_file *cf, frame_data *fd, const gchar *new_comment);
+gboolean cf_set_modified_block(capture_file *cf, frame_data *fd, const wtap_block_t new_block);
 
 /**
  * What types of comments does this file have?
